/*
 * jQuery Attach
 * Simple jQuery plugin to ensure one-time behavior binding
 * (c) 2016 Joshua Cerbito - https://github.com/joshuacerbito/jquery-attach-behavior.git
 * Released under the ISC license
 */

(function($) {
  'use strict';

  $.fn.attachBehavior = function(trigger, cb) {
    if (!!this.binding) {
      throw Error('This function has already been attached to event "' + trigger + '"');
    } else {
      $(this).on(trigger, function(evt) {
        if (typeof cb === 'function') {
          cb.apply(this, arguments);
        }
      });

      this.binding = {
        trigger: trigger,
        callback: cb
      };
    }
  };

  $.fn.detachBehavior = function(trigger, cb) {
    if (!!this.binding) {
      $(this).off(trigger);
    }

    this.binding = null;
  };

  $.fn.getBehavior = function() {
    return this.binding;
  };
})(jQuery);
